@@ -5,6 +5,5 @@ var thread_loop_8c =
     [ "pw_thread_loop_events_destroy", "thread-loop_8c.html#ad45129e1e319f962e8c02a8ea3581779", null ],
     [ "pw_thread_loop_events_emit", "thread-loop_8c.html#ac2a9343e6ff53df4e889a5134ed4eb5c", null ],
     [ "pw_thread_loop_add_listener", "thread-loop_8c.html#a8d4eb52646e76b9e494b7e72b18f329b", null ],
-    [ "pw_thread_loop_get_loop", "thread-loop_8c.html#adaa5c36cb85b928d79c014b6f9117c5e", null ],
-    [ "pw_thread_loop_new_full", "thread-loop_8c.html#a6c6016e24cac0d764d1da02e6c8fd7f2", null ]
+    [ "pw_thread_loop_get_loop", "thread-loop_8c.html#adaa5c36cb85b928d79c014b6f9117c5e", null ]
 ];
\ No newline at end of file
